pub trait PutAddress {
// Required method
fn put_address(&self, addr: usize, buf: &[u8]) -> Result<()>;
}Expand description
A trait that defines that it is possible to put a buffer into the memory of something represented by a type.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".